@@ -73,6 +73,12 @@ window.SweetTooth = function () {
 			var ready = sendResolveExtensionMessage("initialize", "properties", null);
 
 			ready.then(function (response) {
+				if(!response.shellVersion)
+				{
+					apiObject.apiVersion = null;
+					return;
+				}
+
 				apiObject.shellVersion = response.shellVersion;
 				apiObject.versionValidationEnabled = response.versionValidationEnabled;
 
@@ -100,6 +106,8 @@ window.SweetTooth = function () {
 					});
 				}
 			}, function (message) {
+				apiObject.apiVersion = null;
+
 				require(['messages'], function (messages) {
 					messages.addWarning(message ? message : GSC.getMessage('no_host_connector'));
 				})
